@@ -28,7 +28,7 @@
 /* specific prior written permission of the institution or contributor.       */
 /******************************************************************************/
   
-#include <stdio.h>
+#include <cstdio>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -382,7 +382,7 @@ XrdOucTList *XrdCmsBlackList::Flatten(XrdOucTList *tList, int tPort)
 /******************************************************************************/
   
 bool XrdCmsBlackList::GetBL(XrdOucTList  *&bList,
-                            XrdOucTList **&rList, int &rcnt)
+                            XrdOucTList **&rList, int &rcnt, bool isInit)
 {
    static int msgCnt = 0;
    XrdOucEnv myEnv;
@@ -446,7 +446,7 @@ bool XrdCmsBlackList::GetBL(XrdOucTList  *&bList,
          if (!AddBL(bAnchor, hsp, rAnchor, rsp)) aOK = false;
         }
 
-// Now check if any errors occured during file i/o
+// Now check if any errors occurred during file i/o
 //
    if ((retc = blFile.LastError()))
       {Say.Emsg("GetBL", retc, rEmsg, blFN); aOK = false;}
@@ -455,7 +455,7 @@ bool XrdCmsBlackList::GetBL(XrdOucTList  *&bList,
 // Return ending status
 //
    blFile.Close();
-   bList = (aOK ? bAnchor.Export() : 0);
+   bList = ((aOK || isInit) ? bAnchor.Export() : nullptr);
    rList = rAnchor[1].Array(rcnt);
    return aOK;
 }
@@ -494,7 +494,7 @@ void XrdCmsBlackList::Init(XrdScheduler *sP,   XrdCmsCluster *cP,
 //
    if (!stat(blFN, &Stat))
       {blTime = Stat.st_mtime;
-       GetBL(blReal, blRedr, blRcnt);
+       GetBL(blReal, blRedr, blRcnt, /* isInit = */ true);
        if (blReal) blMN.Ring();
       }
 
