@@ -28,9 +28,9 @@
 /* specific prior written permission of the institution or contributor.       */
 /******************************************************************************/
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
   
 #include "XrdCms/XrdCmsClientMsg.hh"
 #include "XrdCms/XrdCmsParser.hh"
