@@ -452,7 +452,7 @@ namespace XrdEc
         opens.emplace_back( OpenOnly( *dataarchs[url], url, false ) );
     }
 
-    auto pipehndl = [=]( const XrdCl::XRootDStatus &st )
+    auto pipehndl = [handler,this]( const XrdCl::XRootDStatus &st )
                     { // set the central directories in ZIP archives (if we use metadata files)
                       auto itr = dataarchs.begin();
                       for( ; itr != dataarchs.end() ; ++itr )
@@ -462,7 +462,7 @@ namespace XrdEc
                         if( zipptr->openstage == XrdCl::ZipArchive::NotParsed )
                           zipptr->SetCD( metadata[url] );
                         else if( zipptr->openstage != XrdCl::ZipArchive::Done && !metadata.empty() )
-                          AddMissing( metadata[url] );
+                          this->AddMissing( metadata[url] );
                         auto itr = zipptr->cdmap.begin();
                         for( ; itr != zipptr->cdmap.end() ; ++itr )
                         {
@@ -700,12 +700,12 @@ namespace XrdEc
     XrdCl::Fwd<void*>    rdbuff;
 
     return XrdCl::Open( *file, url, XrdCl::OpenFlags::Read ) >>
-             [=]( XrdCl::XRootDStatus &st, XrdCl::StatInfo &info ) mutable
+             [index, size, rdbuff, rdsize, this]( XrdCl::XRootDStatus &st, XrdCl::StatInfo &info ) mutable
              {
                if( !st.IsOK() )
                {
                  if( index + 1 < size )
-                   XrdCl::Pipeline::Replace( ReadMetadata( index + 1 ) );
+                   XrdCl::Pipeline::Replace( this->ReadMetadata( index + 1 ) );
                  return;
                }
                // prepare the args for the subsequent operation
@@ -713,19 +713,19 @@ namespace XrdEc
                rdbuff = new char[info.GetSize()];
              }
          | XrdCl::Read( *file, 0, rdsize, rdbuff ) >>
-             [=]( XrdCl::XRootDStatus &st, XrdCl::ChunkInfo &ch )
+             [index, size, this]( XrdCl::XRootDStatus &st, XrdCl::ChunkInfo &ch )
              {
                if( !st.IsOK() )
                {
                  if( index + 1 < size )
-                   XrdCl::Pipeline::Replace( ReadMetadata( index + 1 ) );
+                   XrdCl::Pipeline::Replace( this->ReadMetadata( index + 1 ) );
                  return;
                }
                // now parse the metadata
                if( !ParseMetadata( ch ) )
                {
                  if( index + 1 < size )
-                   XrdCl::Pipeline::Replace( ReadMetadata( index + 1 ) );
+                   XrdCl::Pipeline::Replace( this->ReadMetadata( index + 1 ) );
                  return;
                }
              }
@@ -736,7 +736,7 @@ namespace XrdEc
                  XrdCl::Pipeline::Ignore(); // ignore errors, we don't really care
              }
          | XrdCl::Final(
-             [rdbuff, file]( const XrdCl::XRootDStatus& )
+             [rdbuff]( const XrdCl::XRootDStatus& )
              {
                // deallocate the buffer if necessary
                if( rdbuff.Valid() )
@@ -756,7 +756,7 @@ namespace XrdEc
   {
     std::string url = objcfg.GetDataUrl( index );
     return XrdCl::GetXAttr( dataarchs[url]->GetFile(), "xrdec.filesize" ) >>
-        [index, this]( XrdCl::XRootDStatus &st, std::string &size)
+        [index,this]( XrdCl::XRootDStatus &st, std::string &size)
         {
           if( !st.IsOK() )
           {
@@ -963,7 +963,7 @@ namespace XrdEc
 		hostPipes.emplace_back(
 				XrdCl::VectorRead(XrdCl::Ctx<XrdCl::File>(dataarchs[objcfg.GetDataUrl(i)]->archive),
 						partList, nullptr, timeout)
-						>> [=](const XrdCl::XRootDStatus &st, XrdCl::VectorReadInfo ch) mutable
+						>> [i, log, timeout, blockMap, requestedChunks, this](const XrdCl::XRootDStatus &st, XrdCl::VectorReadInfo ch) mutable
 						{
 								auto it = requestedChunks.begin();
 								while(it!=requestedChunks.end())
@@ -981,7 +981,7 @@ namespace XrdEc
 										if(!st.IsOK())
 										{
 											log->Dump(XrdCl::XRootDMsg, "EC Vector Read of host %zu failed entirely.", i);
-											MissingVectorRead(currentBlock, blkid, strpid, timeout);
+											this->MissingVectorRead(currentBlock, blkid, strpid, timeout);
 										}
 										else{
 											uint32_t orgcksum = 0;
@@ -993,7 +993,7 @@ namespace XrdEc
 											if( !st.IsOK() )
 											{
 												log->Dump(XrdCl::XRootDMsg, "EC Vector Read: Couldn't read CRC32 from CD.");
-												MissingVectorRead(currentBlock, blkid, strpid, timeout);
+												this->MissingVectorRead(currentBlock, blkid, strpid, timeout);
 												continue;
 											}
 											//---------------------------------------------------
@@ -1003,7 +1003,7 @@ namespace XrdEc
 											if( orgcksum != cksum )
 											{
 												log->Dump(XrdCl::XRootDMsg, "EC Vector Read: Wrong checksum for block %zu stripe %zu.", blkid, strpid);
-												MissingVectorRead(currentBlock, blkid, strpid, timeout);
+												this->MissingVectorRead(currentBlock, blkid, strpid, timeout);
 												continue;
 											}
 											else{
@@ -1020,10 +1020,10 @@ namespace XrdEc
 	  }
 	  }
 
-	  auto finalPipehndl = [=] (const XrdCl::XRootDStatus &st) mutable {
+	  auto finalPipehndl = [handler, log, blockMap, chunks, globalBuffer, this] (const XrdCl::XRootDStatus &st) mutable {
 		  // wait until all missing chunks are corrected (uses single reads to get parity stripes)
 		  std::unique_lock<std::mutex> lk(missingChunksMutex);
-		  waitMissing.wait(lk, [=] { return missingChunksVectorRead.size() == 0;});
+		  waitMissing.wait(lk, [this] { return this->missingChunksVectorRead.size() == 0;});
 
 		  bool failed = false;
 		  for(size_t index = 0; index < chunks.size(); index++){
