@@ -813,7 +813,7 @@ static int xrootdfs_read(const char *path, char *buf, size_t size, off_t offset,
     int res;
 
     fd = (int) fi->fh;
-    if (fi->flags & O_RDWR) XrdFfsWcache_flush(fd);
+    if ((fi->flags & O_ACCMODE) == O_RDWR) XrdFfsWcache_flush(fd);
 
     if (usingEC)
     {
@@ -828,7 +828,7 @@ static int xrootdfs_read(const char *path, char *buf, size_t size, off_t offset,
         size = (size_t)(fsize - offset) > size ? size : fsize - offset; 
         // Restrict the use of read cache to O_DIRECT use case 
         // See comment in XRdFfsWcache_pread()
-        if ( ! (fi->flags & O_RDWR) && (fi->flags & O_DIRECT) )
+        if ( ((fi->flags & O_ACCMODE) != O_RDWR) && (fi->flags & O_DIRECT) )
             res = XrdFfsWcache_pread(fd, buf, size, offset);
         else
             res = XrdFfsPosix_pread(fd, buf, size, offset);
@@ -948,7 +948,7 @@ static int xrootdfs_release(const char *path, struct fuse_file_info *fi)
 
     return 0;
 */
-    if (xrootdfs.cns == NULL || (fi->flags & 0100001) == (0100000 | O_RDONLY))
+    if (xrootdfs.cns == NULL)
         return 0;
 
     int res;
