@@ -28,8 +28,8 @@
 /* specific prior written permission of the institution or contributor.       */
 /******************************************************************************/
 
-#include <stdio.h>
-#include <string.h>
+#include <cstdio>
+#include <cstring>
 #include <strings.h>
 #include <utime.h>
 #include <sys/param.h>
@@ -384,7 +384,7 @@ const char *XrdFrmPurge::Eligible(XrdFrmFileset *sP, time_t &xTime, int hTime)
 //
    if (sP->pinInfo.Attr.Flags & XrdFrcXAttrPin::pinIdle
    &&  sP->pinInfo.Attr.pinTime > static_cast<long long>(xTime))
-      return "is pin defered";
+      return "is pin deferred";
    return 0;
 }
 
