@@ -96,6 +96,14 @@ bool XrdHttpReadRangeHandler::isFullFile()
   return rawUserRanges_.empty();
 }
 
+//------------------------------------------------------------------------------
+//! return the maximum number of ranges that may be requested
+//------------------------------------------------------------------------------
+size_t XrdHttpReadRangeHandler::getMaxRanges() const
+{
+  return rawUserRanges_.empty() ? 1 : rawUserRanges_.size();
+}
+
 //------------------------------------------------------------------------------
 //! indicates a single range (implied whole file, or single range) or empty file
 //------------------------------------------------------------------------------
