@@ -37,6 +37,7 @@
  */
 
 
+#include "XrdHttpUtils.hh"
 
 #include <cstring>
 #include <openssl/hmac.h>
@@ -44,15 +45,14 @@
 #include <openssl/buffer.h>
 #include <openssl/err.h>
 #include <openssl/ssl.h>
+# include "sys/param.h"
 
 #include <pthread.h>
 #include <memory>
 #include <vector>
 #include <algorithm>
 
-#include "XProtocol/XPtypes.hh"
 #include "XrdSec/XrdSecEntity.hh"
-# include "sys/param.h"
 #include "XrdOuc/XrdOucString.hh"
 
 #if OPENSSL_VERSION_NUMBER < 0x10100000L
@@ -496,5 +496,168 @@ char *escapeXML(const char *str) {
   return r;
 }
 
+int mapXrdErrToHttp(XErrorCode xrdError) {
 
+  int errNo = XProtocol::toErrno(xrdError);
+  return mapErrNoToHttp(errNo);
 
+}
+
+int mapErrNoToHttp(int errNo) {
+
+  switch (errNo) {
+
+    case EACCES:
+    case EROFS:
+    case EPERM:
+      return HTTP_FORBIDDEN;
+
+    case EAUTH:
+      return HTTP_UNAUTHORIZED;
+
+    case ENOENT:
+      return HTTP_NOT_FOUND;
+
+    case EEXIST:
+    case EISDIR:
+    case ENOTDIR:
+    case ENOTEMPTY:
+      return HTTP_CONFLICT;
+
+    case EXDEV:
+      return HTTP_UNPROCESSABLE_ENTITY;
+
+    case ENAMETOOLONG:
+      return HTTP_URI_TOO_LONG;
+
+    case ELOOP:
+      return HTTP_LOOP_DETECTED;
+
+    case ENOSPC:
+    case EDQUOT:
+      return HTTP_INSUFFICIENT_STORAGE;
+
+    case EFBIG:
+      return HTTP_PAYLOAD_TOO_LARGE;
+
+    case EINVAL:
+    case EBADF:
+    case EFAULT:
+    case ENXIO:
+    case ESPIPE:
+    case EOVERFLOW:
+      return HTTP_BAD_REQUEST;
+
+    case ENOTSUP: // EOPNOTSUPP
+      return HTTP_NOT_IMPLEMENTED;
+
+    case EBUSY:
+    case EAGAIN:
+    case EINTR:
+    case ENOMEM:
+    case EMFILE:
+    case ENFILE:
+    case ETXTBSY:
+      return HTTP_SERVICE_UNAVAILABLE;
+
+    case ETIMEDOUT:
+      return HTTP_GATEWAY_TIMEOUT;
+
+    case ECONNREFUSED:
+    case ECONNRESET:
+    case ENETDOWN:
+    case ENETUNREACH:
+    case EHOSTUNREACH:
+    case EPIPE:
+      return HTTP_BAD_GATEWAY;
+
+    default:
+      return HTTP_INTERNAL_SERVER_ERROR;
+  }
+}
+
+std::string httpStatusToString(int status) {
+  switch (status) {
+    // 1xx Informational
+    case 100: return "Continue";
+    case 101: return "Switching Protocols";
+    case 102: return "Processing";
+    case 103: return "Early Hints";
+
+    // 2xx Success
+    case 200: return "OK";
+    case 201: return "Created";
+    case 202: return "Accepted";
+    case 203: return "Non-Authoritative Information";
+    case 204: return "No Content";
+    case 205: return "Reset Content";
+    case 206: return "Partial Content";
+    case 207: return "Multi-Status";
+    case 208: return "Already Reported";
+    case 226: return "IM Used";
+
+    // 3xx Redirection
+    case 300: return "Multiple Choices";
+    case 301: return "Moved Permanently";
+    case 302: return "Found";
+    case 303: return "See Other";
+    case 304: return "Not Modified";
+    case 305: return "Use Proxy";
+    case 307: return "Temporary Redirect";
+    case 308: return "Permanent Redirect";
+
+    // 4xx Client Errors
+    case 400: return "Bad Request";
+    case 401: return "Unauthorized";
+    case 402: return "Payment Required";
+    case 403: return "Forbidden";
+    case 404: return "Not Found";
+    case 405: return "Method Not Allowed";
+    case 406: return "Not Acceptable";
+    case 407: return "Proxy Authentication Required";
+    case 408: return "Request Timeout";
+    case 409: return "Conflict";
+    case 410: return "Gone";
+    case 411: return "Length Required";
+    case 412: return "Precondition Failed";
+    case 413: return "Payload Too Large";
+    case 414: return "URI Too Long";
+    case 415: return "Unsupported Media Type";
+    case 416: return "Range Not Satisfiable";
+    case 417: return "Expectation Failed";
+    case 418: return "I'm a teapot";
+    case 421: return "Misdirected Request";
+    case 422: return "Unprocessable Entity";
+    case 423: return "Locked";
+    case 424: return "Failed Dependency";
+    case 425: return "Too Early";
+    case 426: return "Upgrade Required";
+    case 428: return "Precondition Required";
+    case 429: return "Too Many Requests";
+    case 431: return "Request Header Fields Too Large";
+    case 451: return "Unavailable For Legal Reasons";
+
+    // 5xx Server Errors
+    case 500: return "Internal Server Error";
+    case 501: return "Not Implemented";
+    case 502: return "Bad Gateway";
+    case 503: return "Service Unavailable";
+    case 504: return "Gateway Timeout";
+    case 505: return "HTTP Version Not Supported";
+    case 506: return "Variant Also Negotiates";
+    case 507: return "Insufficient Storage";
+    case 508: return "Loop Detected";
+    case 510: return "Not Extended";
+    case 511: return "Network Authentication Required";
+
+    default:
+      switch (status) {
+        case 100 ... 199: return "Informational";
+        case 200 ... 299: return "Success";
+        case 300 ... 399: return "Redirection";
+        case 400 ... 499: return "Client Error";
+        case 500 ... 599: return "Server Error";
+        default: return "Unknown";
+      }
+  }
+}
