@@ -30,11 +30,11 @@
 
 #include <dirent.h>
 #include <unistd.h>
-#include <errno.h>
+#include <cerrno>
 #include <strings.h>
 #include <signal.h>
-#include <stdio.h>
-#include <time.h>
+#include <cstdio>
+#include <ctime>
 #if defined(AIX) || defined(__solaris__)
 #include <sys/vnode.h>
 #include <sys/mode.h>
@@ -63,7 +63,7 @@
   
 extern XrdSysError OssEroute;
 
-extern XrdOucTrace OssTrace;
+extern XrdSysTrace OssTrace;
 
 /******************************************************************************/
 /*                               d e f i n e s                                */
