@@ -29,10 +29,10 @@
 /******************************************************************************/
 
 #include <unistd.h>
-#include <errno.h>
+#include <cerrno>
 #include <strings.h>
 #include <limits.h>
-#include <stdio.h>
+#include <cstdio>
 #include <sys/param.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -53,7 +53,7 @@
 
 extern XrdSysError OssEroute;
 
-extern XrdOucTrace OssTrace;
+extern XrdSysTrace OssTrace;
   
 /******************************************************************************/
 /*                                R e m d i r                                 */
