@@ -515,13 +515,15 @@ void XrdPosixConfig::SetEnv(const char *kword, int kval)
 //
         if (!strcmp(kword, "DirlistAll"))
            {XrdPosixGlobals::dlFlag = (kval ? XrdCl::DirListFlags::Locate
-                                            : XrdCl::DirListFlags::None);
+                                            : XrdCl::DirListFlags::None) |
+                                      XrdCl::DirListFlags::Stat;
             dlfSet = true;
            }
    else if (!strcmp(kword, "DirlistDflt"))
            {if (!dlfSet)
             XrdPosixGlobals::dlFlag = (kval ? XrdCl::DirListFlags::Locate
-                                            : XrdCl::DirListFlags::None);
+                                            : XrdCl::DirListFlags::None) |
+                                      XrdCl::DirListFlags::Stat;
            }
    else env->PutInt((std::string)kword, kval);
 }
