@@ -85,7 +85,8 @@ XrdPssCks::XrdPssCks(XrdSysError *erP) : XrdCks(erP)
    csTab[0].Len =  4; strcpy(csTab[0].Name, "adler32");
    csTab[1].Len =  4; strcpy(csTab[1].Name, "crc32");
    csTab[2].Len = 16; strcpy(csTab[2].Name, "md5");
-   csLast = 2;
+   csTab[3].Len =  4; strcpy(csTab[3].Name, "crc32c");
+   csLast = 3;
 }
 
 /******************************************************************************/
@@ -121,7 +122,7 @@ int XrdPssCks::Get(const char *Pfn, XrdCksData &Cks)
 
 // Construct the correct url info
 //
-   XrdPssUrlInfo uInfo(Cks.envP, Pfn, cgiBuff, false);
+   XrdPssUrlInfo uInfo(Cks.envP, Pfn, cgiBuff, true);
    uInfo.setID();
 
 // Direct the path to the origin
@@ -169,7 +170,7 @@ int XrdPssCks::Init(const char *ConfigFN, const char *DfltCalc)
 // See if we need to set the default calculation
 //
    if (DfltCalc)
-      {for (i = 0; i < csLast; i++) if (!strcmp(csTab[i].Name, DfltCalc)) break;
+      {for (i = 0; i <= csLast; i++) if (!strcmp(csTab[i].Name, DfltCalc)) break;
        if (i >= csMax)
           {eDest->Emsg("Config", DfltCalc, "cannot be made the default; "
                                            "not supported.");
