@@ -716,9 +716,13 @@ bool XrdSys::IOEvents::Poller::CbkXeq(XrdSys::IOEvents::Channel *cP, int events,
 //
    cP->chStat = Channel::isCBMode;
    chDead     = false;
+   // Detach() may be called after unlocking the channel and would zero the
+   // callback pointer and argument. So keep a copy.
+   CallBack *cb = cP->chCB;
+   void *cba = cP->chCBA;
    cbkMHelp.UnLock();
    IF_TRACE(CbkXeq,cP->chFD,"invoking callback; events=" <<events);
-   cbok = cP->chCB->Event(cP,cP->chCBA, events);
+   cbok = cb->Event(cP,cba, events);
    IF_TRACE(CbkXeq,cP->chFD,"callback returned " <<BOOLNAME(cbok));
 
 // If channel destroyed by the callback, bail really fast. Otherwise, regain
