@@ -175,7 +175,7 @@ int XrdXrootdProtocol::do_PgRead()
                   if (pP->linkAioReq >= as_maxperlnk) pP = 0;
                  }
 
-         if (pP && (aioP = XrdXrootdPgrwAio::Alloc(pP, pP->Response, IO.File)))
+         if (pP && (aioP = XrdXrootdPgrwAio::Alloc(pP, Response, IO.File)))
             {if (!IO.File->aioFob) IO.File->aioFob = new XrdXrootdAioFob;
              aioP->Read(IO.Offset, IO.IOLen);
              return 0;
